@@ -3,7 +3,7 @@ import time
 import json
 
 from LlamaLogsDev.llamaProxy import LlamaProxy
-from LlamaLogsDev.models.aggregateLog import AggregateLog
+from LlamaLogsDev.aggregateLog import AggregateLog
 
 class LogAggregator:
     aggregateLogs = {}
